@@ -22,13 +22,13 @@ from sphinx.util.logging import getLogger
 from sphinx.util.osutil import copyfile
 from sphinx.util.osutil import relative_uri
 
-__version__ = "0.2.0"
+__version__ = "0.2.2"
 
 logger = getLogger(__name__)
 CELL_TYPES = {"markdown": nbf.new_markdown_cell, "code": nbf.new_code_cell}
 REPL_PATTERN = re.compile(r"^(>>>|\.\.\.) ?", re.MULTILINE)
 
-CODE_LANGUAGES = {"default", "python", "pycon3"}
+CODE_LANGUAGES = {"default", "python", "pycon3", "pycon"}
 """The set of languages we support being exported as a notebook."""
 
 
